==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/ContentTypeRequestGroupCriteria.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ContentTypeRequestGroupCriteria.h"
#include "RequestGroup.h"
#include "SingleFileDownloadContext.h"
#include "Util.h"

ContentTypeRequestGroupCriteria::ContentTypeRequestGroupCriteria(const Strings& contentTypes,
								 const Strings& extensions):
  _contentTypes(contentTypes),
  _extensions(extensions) {}

ContentTypeRequestGroupCriteria::~ContentTypeRequestGroupCriteria() {}

bool ContentTypeRequestGroupCriteria::match(const RequestGroup* requestGroup) const
{
  if(forwardMatch(requestGroup->getFilePath(), _extensions)) {
    return true;
  } else {
    SingleFileDownloadContextHandle dctx = requestGroup->getDownloadContext();
    if(dctx.isNull()) {
      return false;
    } else {
      return exactMatch(dctx->getContentType(), _contentTypes);
    }
  }
}

bool ContentTypeRequestGroupCriteria::forwardMatch(const string& target, const Strings& candidates) const
{
  for(Strings::const_iterator itr = candidates.begin(); itr != candidates.end(); ++itr) {
    if(Util::endsWith(target, *itr)) {
      return true;
    }
  }
  return false;
}

bool ContentTypeRequestGroupCriteria::exactMatch(const string& target, const Strings& candidates) const
{
  for(Strings::const_iterator itr = candidates.begin(); itr != candidates.end(); ++itr) {
    if(target == *itr) {
      return true;
    }
  }
  return false;
}

==> aria2_1.8.0.orig.tar.gz: aria2-1.8.0/src/ContentTypeRequestGroupCriteria.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ContentTypeRequestGroupCriteria.h"

#include <algorithm>

#include "RequestGroup.h"
#include "util.h"
#include "FileEntry.h"
#include "DownloadContext.h"

namespace aria2 {

template<typename InputIterator>
bool tailMatch
(InputIterator first, InputIterator last, const std::string& target)
{
  for(; first != last; ++first) {
    if(util::endsWith(target, *first)) {
      return true;
    }
  }
  return false;
}

bool ContentTypeRequestGroupCriteria::match
(const RequestGroup* requestGroup) const
{
  if(requestGroup->getDownloadContext()->getFileEntries().size() != 1) {
    return false;
  }
  if(tailMatch(_extensions.begin(), _extensions.end(),
	       requestGroup->getFirstFilePath())) {
    return true;
  } else {
    return
      std::find(_contentTypes.begin(), _contentTypes.end(),
		requestGroup->getDownloadContext()->getFirstFileEntry()->
		getContentType()) != _contentTypes.end();
  }
}

} // namespace aria2
